==> zzyj-outputvalcount-impl-3.0.0-20220716.021817-54-sources.jar: com/ejianc/business/outputvalcount/bean/MonthlyStatisticsEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度产值统计
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_monthly_statistics")
public class MonthlyStatisticsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="lb_id")
    private Long lbId; // 工程类别id
    @TableField(value="lb_name")
    private String lbName; // 工程类别
    @TableField(value="jglx_id")
    private Long jglxId; // 结构类型id
    @TableField(value="jglx_name")
    private String jglxName; // 结构类型
    @TableField(value="zje")
    private BigDecimal zje; // 总金额
    @TableField(value="zmj")
    private BigDecimal zmj; // 总面积
    @TableField(value="address")
    private String address; // 工程所在地
    @TableField(value="zcrs")
    private Integer zcrs; // 在场从业人数
    @TableField(value="year")
    private Integer year; // 年份
    @TableField(value="month")
    private Integer month; // 月份
    @TableField(value="gczt_id")
    private Long gcztId; // 工程状态id
    @TableField(value="gczt_name")
    private String gcztName; // 工程状态
    @TableField(value="bywccz")
    private BigDecimal bywccz; // 本月完成产值
    @TableField(value="bnwccz")
    private BigDecimal bnwccz; // 自年初累计完成产值
    @TableField(value="kgwccz")
    private BigDecimal kgwccz; // 自开工累计完成产值
    @TableField(value="description")
    private String description; // 形象进度描述
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="measure_type")
    private Long measureType; // 工程度量方式
    @TableField(value="build_unit_id")
    private Long buildUnitId; // 工程父id
    @TableField(value="bild_unit_name")
    private String bildUnitName; // 施工单位
    @TableField(value="zlje")
    private BigDecimal zlje; // 暂列金额
    @TableField(value="stat_date")
    private Date statDate; // 产值统计日期
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目组织id

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }

    public Long getMeasureType() {
        return measureType;
    }

    public void setMeasureType(Long measureType) {
        this.measureType = measureType;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getLbId() {
        return lbId;
    }

    public void setLbId(Long lbId) {
        this.lbId = lbId;
    }
    public String getLbName() {
        return lbName;
    }

    public void setLbName(String lbName) {
        this.lbName = lbName;
    }
    public Long getJglxId() {
        return jglxId;
    }

    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }
    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
    public BigDecimal getZmj() {
        return zmj;
    }

    public void setZmj(BigDecimal zmj) {
        this.zmj = zmj;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Integer getZcrs() {
        return zcrs;
    }

    public void setZcrs(Integer zcrs) {
        this.zcrs = zcrs;
    }
    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }
    public Long getGcztId() {
        return gcztId;
    }

    public void setGcztId(Long gcztId) {
        this.gcztId = gcztId;
    }
    public String getGcztName() {
        return gcztName;
    }

    public void setGcztName(String gcztName) {
        this.gcztName = gcztName;
    }
    public BigDecimal getBywccz() {
        return bywccz;
    }

    public void setBywccz(BigDecimal bywccz) {
        this.bywccz = bywccz;
    }
    public BigDecimal getBnwccz() {
        return bnwccz;
    }

    public void setBnwccz(BigDecimal bnwccz) {
        this.bnwccz = bnwccz;
    }
    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }



    public Long getBuildUnitId() {
        return buildUnitId;
    }

    public void setBuildUnitId(Long buildUnitId) {
        this.buildUnitId = buildUnitId;
    }

    public String getBildUnitName() {
        return bildUnitName;
    }

    public void setBildUnitName(String bildUnitName) {
        this.bildUnitName = bildUnitName;
    }

    public BigDecimal getZlje() {
        return zlje;
    }

    public void setZlje(BigDecimal zlje) {
        this.zlje = zlje;
    }
}

==> zzyj-outputvalcount-impl-3.0.0-20221122.025925-116-sources.jar: com/ejianc/business/outputvalcount/bean/MonthlyStatisticsEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度产值统计
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_monthly_statistics")
public class MonthlyStatisticsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="lb_id")
    private Long lbId; // 工程类别id
    @TableField(value="lb_name")
    private String lbName; // 工程类别
    @TableField(value="jglx_id")
    private Long jglxId; // 结构类型id
    @TableField(value="jglx_name")
    private String jglxName; // 结构类型
    @TableField(value="zje")
    private BigDecimal zje; // 总金额
    @TableField(value="zmj")
    private String zmj; // 总面积
    @TableField(value="address")
    private String address; // 工程所在地
    @TableField(value="zcrs")
    private Integer zcrs; // 在场从业人数
    @TableField(value="year")
    private Integer year; // 年份
    @TableField(value="month")
    private Integer month; // 月份
    @TableField(value="gczt_id")
    private Long gcztId; // 工程状态id
    @TableField(value="gczt_name")
    private String gcztName; // 工程状态
    @TableField(value="bywccz")
    private BigDecimal bywccz; // 本月完成产值
    @TableField(value="bnwccz")
    private BigDecimal bnwccz; // 自年初累计完成产值
    @TableField(value="kgwccz")
    private BigDecimal kgwccz; // 自开工累计完成产值
    @TableField(value="description")
    private String description; // 形象进度描述
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="measure_type")
    private Long measureType; // 工程度量方式
    @TableField(value="build_unit_id")
    private Long buildUnitId; // 工程父id
    @TableField(value="bild_unit_name")
    private String bildUnitName; // 施工单位
    @TableField(value="zlje")
    private BigDecimal zlje; // 暂列金额
    @TableField(value="stat_date")
    private Date statDate; // 产值统计日期
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目组织id

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }

    public Long getMeasureType() {
        return measureType;
    }

    public void setMeasureType(Long measureType) {
        this.measureType = measureType;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getLbId() {
        return lbId;
    }

    public void setLbId(Long lbId) {
        this.lbId = lbId;
    }
    public String getLbName() {
        return lbName;
    }

    public void setLbName(String lbName) {
        this.lbName = lbName;
    }
    public Long getJglxId() {
        return jglxId;
    }

    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }
    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
    public String getZmj() {
        return zmj;
    }

    public void setZmj(String zmj) {
        this.zmj = zmj;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Integer getZcrs() {
        return zcrs;
    }

    public void setZcrs(Integer zcrs) {
        this.zcrs = zcrs;
    }
    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }
    public Long getGcztId() {
        return gcztId;
    }

    public void setGcztId(Long gcztId) {
        this.gcztId = gcztId;
    }
    public String getGcztName() {
        return gcztName;
    }

    public void setGcztName(String gcztName) {
        this.gcztName = gcztName;
    }
    public BigDecimal getBywccz() {
        return bywccz;
    }

    public void setBywccz(BigDecimal bywccz) {
        this.bywccz = bywccz;
    }
    public BigDecimal getBnwccz() {
        return bnwccz;
    }

    public void setBnwccz(BigDecimal bnwccz) {
        this.bnwccz = bnwccz;
    }
    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }



    public Long getBuildUnitId() {
        return buildUnitId;
    }

    public void setBuildUnitId(Long buildUnitId) {
        this.buildUnitId = buildUnitId;
    }

    public String getBildUnitName() {
        return bildUnitName;
    }

    public void setBildUnitName(String bildUnitName) {
        this.bildUnitName = bildUnitName;
    }

    public BigDecimal getZlje() {
        return zlje;
    }

    public void setZlje(BigDecimal zlje) {
        this.zlje = zlje;
    }
}
